Struct Locked
struct Locked<'a, T: 'a> { ... }
A locked value acquired from a TryLock.
The type represents an exclusive view at the underlying value. The lock is released when this type is dropped.
This type derefs to the underlying value.
Implementations
impl<'a, T> Deref for Locked<'a, T>
fn deref(self: &Self) -> &T
impl<'a, T> DerefMut for Locked<'a, T>
fn deref_mut(self: &mut Self) -> &mut T
impl<'a, T> Drop for Locked<'a, T>
fn drop(self: &mut Self)
impl<'a, T> Freeze for Locked<'a, T>
impl<'a, T> RefUnwindSafe for Locked<'a, T>
impl<'a, T> Send for Locked<'a, T>
impl<'a, T> Sync for Locked<'a, T>
impl<'a, T> Unpin for Locked<'a, T>
impl<'a, T> UnsafeUnpin for Locked<'a, T>
impl<'a, T> UnwindSafe for Locked<'a, T>
impl<'a, T: fmt::Debug> Debug for Locked<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<P, T> Receiver for Locked<'a, T>
impl<T> Any for Locked<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Locked<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Locked<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Locked<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Locked<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Locked<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Locked<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>